@@ -213,9 +213,7 @@ with_mock_api({
       fixed = TRUE
     )
   })
-})
 
-with_mock_api({
   test_that("content_restart() calls the correct endpoint", {
     client <- Connect$new(server = "https://connect.example", api_key = "not-a-key")
     x <- content_item(client, "8f37d6e0-3395-4a2c-aa6a-d7f2fe1babd0")
@@ -231,9 +229,7 @@ with_mock_api({
       fixed = TRUE
     )
   })
-})
 
-with_mock_api({
   test_that("content$default_variant gets the default variant", {
     client <- Connect$new(server = "http://connect.example", api_key = "not-a-key")
     x <- content_item(client, "951bf3ad-82d0-4bca-bba8-9b27e35c49fa")
@@ -247,6 +243,7 @@ with_mock_api({
 test_that("get_jobs() using the old and new endpoints returns sensible results", {
   with_mock_api({
     client <- Connect$new(server = "http://connect.example", api_key = "not-a-key")
+
     item <- content_item(client, "8f37d6e0")
     jobs_v1 <- get_jobs(item)
   })
@@ -255,23 +252,54 @@ test_that("get_jobs() using the old and new endpoints returns sensible results",
     jobs_v0 <- get_jobs(item)
   })
 
+  # Connect 2025.01.0 also provides `content_id` and `content_guid` columns.
+  # For older versions, `connectapi` adds them, so objects should all be identical.
+  with_mock_dir("2025.01.0", {
+    jobs_v1_2025_01_0 <- get_jobs(item)
+  })
+
   # Columns we expect to be identical
   common_cols <- c(
-    "id", "pid", "key", "app_id", "variant_id", "bundle_id", "start_time",
-    "end_time", "tag", "exit_code", "hostname"
+    "id", "pid", "key", "app_id", "app_guid", "content_id", "content_guid",
+    "variant_id", "bundle_id", "start_time", "end_time", "tag", "exit_code",
+    "hostname"
   )
   expect_identical(
     jobs_v1[common_cols],
     jobs_v0[common_cols]
   )
+  expect_identical(
+    jobs_v1[common_cols],
+    jobs_v1_2025_01_0[common_cols]
+  )
 
   # Status columns line up as expected
   expect_equal(jobs_v1$status, c(0L, 0L, 2L, 2L, 2L, 2L))
   expect_equal(jobs_v0$status, c(0L, 0L, NA, NA, NA, NA))
+  expect_equal(jobs_v1_2025_01_0$status, c(0L, 0L, 2L, 2L, 2L, 2L))
 })
 
 with_mock_api({
   client <- Connect$new(server = "http://connect.example", api_key = "not-a-key")
+  test_that("get_job_list() returns expected data", {
+    item <- content_item(client, "8f37d6e0")
+    job_list <- get_job_list(item)
+
+    expect_equal(
+      purrr::map_chr(job_list, "id"),
+      c("40793542", "40669829", "40097386", "40096649", "40080413", "39368207")
+    )
+
+    expect_equal(
+      purrr::map_chr(job_list, "app_guid"),
+      rep("8f37d6e0", 6)
+    )
+
+    expect_equal(
+      purrr::map(job_list, "client"),
+      list(client, client, client, client, client, client)
+    )
+  })
 
   test_that("terminate_jobs() returns expected data when active jobs exist", {
     item <- content_item(client, "8f37d6e0")
@@ -324,3 +352,35 @@ test_that("an error is raised when terminate_jobs() calls a bad URL", {
     )
   })
 })
+
+test_that("get_log() gets job logs", {
+  with_mock_api({
+    client <- Connect$new(server = "http://connect.example", api_key = "not-a-key")
+    item <- content_item(client, "8f37d6e0")
+    job_list <- get_job_list(item)
+    # This job's log is present at {mock_dir}/v1/content/8f37d6e0/jobs/mxPGVOMVk6f8dso2/log.json.
+    job <- purrr::keep(job_list, ~ .x$key == "mxPGVOMVk6f8dso2")[[1]]
+    log <- get_log(job)
+    expect_identical(
+      log,
+      tibble::tibble(
+        source = c("stderr", "stderr", "stderr"),
+        timestamp = structure(
+          c(1733512169.9480169, 1733512169.9480703, 1733512169.9480758),
+          tzone = "UTC",
+          class = c("POSIXct", "POSIXt")
+        ),
+        data = c(
+          "[rsc-session] Content GUID: 8f37d6e0",
+          "[rsc-session] Content ID: 52389",
+          "[rsc-session] Bundle ID: 127015"
+        )
+      )
+    )
+
+    expect_GET(
+      get_log(job, max_log_lines = 10),
+      "http://connect.example/__api__/v1/content/8f37d6e0/jobs/mxPGVOMVk6f8dso2/log?maxLogLines=10"
+    )
+  })
+})
